/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {fetch} from 'frontend-js-web';

const apiFetch = (url, method = 'get', data, contentType, headers) => {
	const request = {
		headers: getHeaders(headers),
		method: method.toUpperCase()
	};

	if (method === 'post' || method === 'put') {
		if (contentType === 'application/json') {
			request.body = JSON.stringify(data);
			request.headers['Content-Type'] = 'application/json';
		}
		else if (contentType === 'multipart/form-data') {
			const formData = new FormData();

			for (let i = 0; i < data.length; i++) {
				const name = data[i];
				formData.append(name, data[name]);
			}

			request.body = formData;
		}
	}

	return fetch(url, request).then(res => {
		let retVal;

		if (method === 'delete' && res.status === 204) {
			retVal = 'Deleted Successfully';
		}
		else {
			retVal = res.json();
		}

		return retVal;
	});

	function getHeaders(headers) {
		if (headers && headers.filter(obj => obj.key).length) {
			return Object.assign(
				...headers.map(obj => ({[obj.key]: obj.value}))
			);
		}

		return {};
	}
};

export default apiFetch;
